{% load menu_tags wagtailcore_tags %}
{% get_site_root as site_root %}

<ul class="menu-depth-{{ depth }}">
    {% for menuitem in menuitems %}
        <li class="{% if menuitem.has_children %}has-children{% endif %}{% if menuitem.active %} active{% endif %}">
            <a href="{% pageurl menuitem %}">{{ menuitem.title }}</a>
            {% if menuitem.has_children %}
                {% main_menu parent=menuitem %}
            {% endif %}
        </li>
    {% endfor %}
</ul>
